---
title: "formatdown"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{formatdown}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

Please see the formatdown website for full documentation:

  * <https://graphdr.github.io/formatdown/index.html>
  
The website also includes articles describing typical applications in detail: 

  * [Index of articles](https://graphdr.github.io/formatdown/articles/index.html)
  



